@@ -9,13 +9,16 @@ from emora_stdm.state_transition_dialogue_manager.natex_nlu import NatexNLU
 from typing import Union, Set, List, Dict, Callable, Tuple, NoReturn, Any
 import nltk
 from spacy.pipeline import EntityRecognizer
+import traceback
 import spacy
+import sys
 try:
     nlp = spacy.load("en_core_web_sm")
-except IOError:
-    print('Error loading Spacy')
-    print('Please run the following command:')
-    print('python -m spacy download en_core_web_sm')
+except Exception as e:
+    traceback.print_exc()
+    print('Error loading Spacy', file=sys.stderr)
+    print('Please run the following command:', file=sys.stderr)
+    print('python -m spacy download en_core_web_sm', file=sys.stderr)
 try:
     nltk.data.find('wordnet')
 except:
